
-- splits the block so that every square is as low as possible ---------------

function split_get_highest_square(x)
    local y
    local height
    local y_min
    local found

    height=u61_get_height()
    y_min=height
    found=0

    y=0
    while y<height and found==0 do
        if u61_get_square_color(x,y)>=0 then
            found=1
            y_min=y
        end
        y=y+1
    end

    return y_min
end

function split_block()
    local x
    local y
    local y_min
    local size
    local i
    local width
    local height

    width=u61_get_width()
    size=u61_get_nb_items()
    x=0
    while x<width do
        y_min=split_get_highest_square(x)
        y=y_min-1
        while y>=0 do
            i=0
            while (i<size) do
                if (u61_get_block_x()+u61_get_item_x(i)==x
                    and u61_get_block_y()+u61_get_item_y(i)==y) then
                    u61_set_item_y(i,y_min-u61_get_block_y()-1)
                    y_min=y_min-1
                end
                i=i+1
            end
            y=y-1
        end 
        x=x+1
    end
end


